@@ -10,10 +10,10 @@ def tokenize_en(text: str) -> List[str]:
 
 
 if __name__ == '__main__':
-    model = KeyedVectors.load('wiki_mecab-ipadic-neologd.kv')
-    swem_embed = swem.SWEM(model, tokenizer=tokenize_en)
+    kv = KeyedVectors.load('wiki_mecab-ipadic-neologd.kv')
+    swem_embed = swem.SWEM(kv, tokenizer=tokenize_en)
 
-    doc = 'This is an implementation of SWEM.'
+    doc: str = 'This is an implementation of SWEM.'
     embed = swem_embed.infer_vector(doc, method='max')
     print(embed)
     print(embed.shape)
